@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Data::InputMonster;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 # ABSTRACT: consume data from multiple sources, best first; om nom nom!
 
@@ -43,7 +43,13 @@ sub _assert_field_spec_ok {
 
 
 sub consume {
-  my ($self, $input) = @_;
+  my ($self, $input, $arg) = @_;
+  $arg ||= {};
+
+  my %no_default_for
+    = (! $arg->{no_default_for})   ? ()
+    : (ref $arg->{no_default_for}) ? (map {$_=>1} @{$arg->{no_default_for}})
+    : ($arg->{no_default_for} => 1);
 
   my $field  = $self->{fields};
   my %output;
@@ -77,7 +83,7 @@ sub consume {
       next FIELD;
     }
 
-    my $default = $spec->{default};
+    my $default = $no_default_for{ $field_name } ? undef : $spec->{default};
     $output{ $field_name } = ref $default ? $default->() : $default;
   }
 
@@ -97,7 +103,7 @@ Data::InputMonster - consume data from multiple sources, best first; om nom nom!
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
@@ -155,12 +161,17 @@ parameters, see below.
 
 =head2 consume
 
-    my $result = $monster->consume($input);
+    my $result = $monster->consume($input, \%arg);
 
 This method processes the given input and returns a hashref of the finally
 accepted values.  C<$input> can be anything; it is up to the field definitions
 to expect and handle the data you plan to feed the monster.
 
+Valid arguments are:
+
+    no_default_for - a field name or arrayref of field names for which to NOT
+                     fall back to default values
+
 =head1 AUTHOR
 
   Ricardo SIGNES <rjbs@cpan.org>
